@@ -61,6 +61,8 @@ class ModelCheckpoint(Callback):
         return None
 
     def on_epoch_end(self, epoch, logs: dict = {}):
+        # fix a bug:
+        if not self.is_main_process: return
         if "test" in logs:
             value = self.get_indicators_values(self.indicator, logs["test"])
         else:
@@ -97,12 +99,13 @@ class ModelCheckpoint(Callback):
         """保存关注的指标(indicator)最优的模型"""
         model = self.model
         optimizer = self.optimizer
-        if value < self.indicator_val and inverse:
+        if value > self.indicator_val and inverse:
             # indicator指标，值越小，性能越好
-            self.indicator_val = value
-        elif value > self.indicator_val:
+            return
+        elif value < self.indicator_val:
             # indicator指标，值越大，性能越好
-            self.indicator_val = value
+            return
+        self.indicator_val = value
         model_file = os.path.join(model_root, "best_model_{:0=3d}_{:.4f}.pth".format(epoch, value))
         file_utils.remove_prefix_files(model_root, "best_model_*")
         torch.save(model.module.state_dict(), model_file)
