@@ -17,10 +17,13 @@ def get_scheduler(scheduler, optimizer, lr_init, num_epochs, num_steps, **kwargs
                                    milestones=kwargs["milestones"],
                                    nums_warn_up=kwargs["nums_warn_up"])
     elif scheduler == "cosine":
+        # 余弦退火学习率调整策略
         lr_scheduler = CosineAnnealingLR(optimizer,
                                          num_epochs,
                                          num_steps=num_steps,
-                                         lr_init=lr_init)
+                                         lr_init=lr_init,
+                                         nums_warn_up=kwargs["nums_warn_up"]
+                                         )
     else:
-        raise Exception("Error:{}".format(scheduler))
+        raise Exception("Error: scheduler type: {}".format(scheduler))
     return lr_scheduler
